@@ -85,7 +85,6 @@
 #'   each named state can be used by enclosing the set of statements with `{ }`.
 #' 
 #' @examples 
-#' if (interactive()) {
 #' 
 #' # For these examples, we will use the
 #' # included `small_table` dataset
@@ -162,6 +161,8 @@
 #' x_list <- get_agent_x_list(agent_2)
 #' x_list$warn
 #'
+#' if (interactive()) {
+#'
 #' # In the context of using validation
 #' # functions directly on data (i.e., no
 #' # involvement of an agent) we want to
@@ -261,17 +262,24 @@ normalize_fns_list <- function(fns) {
     )
   
   if (!all(are_formulas)) {
-    stop("All components of the `fns` list must be formulas.", call. = FALSE)
+    
+    stop(
+      "All components of the `fns` list must be formulas.",
+      call. = FALSE
+    )
   }
   
   if ("" %in% names(fns)) {
+    
     stop("The `fns` list must be fully named.", call. = FALSE)
   }
   
   if (!all(names(fns) %in% c("warn", "stop", "notify"))) {
-    stop("All names in the `fns` list must be one of `warn`, ",
-         "`stop`, or `notify`.",
-         call. = FALSE)
+    
+    stop(
+      "All names in the `fns` list must be one of `warn`, `stop`, or `notify`.",
+      call. = FALSE
+    )
   }
   
   fns
@@ -280,14 +288,20 @@ normalize_fns_list <- function(fns) {
 normalize_fraction_count <- function(x) {
   
   if (!is.null(x) && !any(c(inherits(x, "numeric"), inherits(x, "integer")))) {
-    stop("All values provided to `action_levels()` must be either ",
-         "`numeric` or `integer` types.",
-         call. = FALSE)
+    
+    stop(
+      "All values provided to `action_levels()` must be either ",
+      "`numeric` or `integer` types.",
+      call. = FALSE
+    )
   }
   
   if (!is.null(x) && x <= 0) {
-    stop("All values provided to `action_levels()` must be `>=0`.",
-         call. = FALSE)
+    
+    stop(
+      "All values provided to `action_levels()` must be `>=0`.",
+      call. = FALSE
+    )
   }
   
   if (!is.null(x)) {
