@@ -32,16 +32,52 @@
 #' number of rows in the table (after any `preconditions` have been applied).
 #' 
 #' @section Preconditions:
-#' Having table `preconditions` means **pointblank** will mutate the table just
-#' before interrogation. Such a table mutation is isolated in scope to the
-#' validation step(s) produced by the validation function call. Using
-#' **dplyr** code is suggested here since the statements can be translated to
-#' SQL if necessary. The code is most easily supplied as a one-sided **R**
-#' formula (using a leading `~`). In the formula representation, the `.` serves
-#' as the input data table to be transformed (e.g., 
-#' `~ . %>% dplyr::mutate(col_a = col_b + 10)`). Alternatively, a function could
-#' instead be supplied (e.g., 
-#' `function(x) dplyr::mutate(x, col_a = col_b + 10)`).
+#' Providing expressions as `preconditions` means **pointblank** will preprocess
+#' the target table table during interrogation as a preparatory step. It might
+#' happen that a particular validation requires a calculated column, some
+#' filtering of rows, or the addition of columns via a join, etc. Especially for
+#' an *agent*-based report this can be advantageous since we can develop a large
+#' validation plan with a single target table and make minor adjustments to it,
+#' as needed, along the way.
+#'
+#' The table mutation is totally isolated in scope to the validation step(s)
+#' where `preconditions` is used. Using **dplyr** code is suggested here since
+#' the statements can be translated to SQL if necessary (i.e., if the target
+#' table resides in a database). The code is most easily supplied as a one-sided
+#' **R** formula (using a leading `~`). In the formula representation, the `.`
+#' serves as the input data table to be transformed (e.g., `~ . %>%
+#' dplyr::mutate(col_b = col_a + 10)`). Alternatively, a function could instead
+#' be supplied (e.g., `function(x) dplyr::mutate(x, col_b = col_a + 10)`).
+#' 
+#' @section Segments:
+#' By using the `segments` argument, it's possible to define a particular
+#' validation with segments (or row slices) of the target table. An optional
+#' expression or set of expressions that serve to segment the target table by
+#' column values. Each expression can be given in one of two ways: (1) as column
+#' names, or (2) as a two-sided formula where the LHS holds a column name and
+#' the RHS contains the column values to segment on.
+#' 
+#' As an example of the first type of expression that can be used,
+#' `vars(a_column)` will segment the target table in however many unique values
+#' are present in the column called `a_column`. This is great if every unique
+#' value in a particular column (like different locations, or different dates)
+#' requires it's own repeating validation.
+#'
+#' With a formula, we can be more selective with which column values should be
+#' used for segmentation. Using `a_column ~ c("group_1", "group_2")` will
+#' attempt to obtain two segments where one is a slice of data where the value
+#' `"group_1"` exists in the column named `"a_column"`, and, the other is a
+#' slice where `"group_2"` exists in the same column. Each group of rows
+#' resolved from the formula will result in a separate validation step.
+#'
+#' If there are multiple `columns` specified then the potential number of
+#' validation steps will be `m` columns multiplied by `n` segments resolved.
+#'
+#' Segmentation will always occur after `preconditions` (i.e., statements that
+#' mutate the target table), if any, are applied. With this type of one-two
+#' combo, it's possible to generate labels for segmentation using an expression
+#' for `preconditions` and refer to those labels in `segments` without having to
+#' generate a separate version of the target table.
 #' 
 #' @section Actions:
 #' Often, we will want to specify `actions` for the validation. This argument,
@@ -81,6 +117,7 @@
 #'   col_vals_expr(
 #'     expr = ~ a %% 1 == 0,
 #'     preconditions = ~ . %>% dplyr::filter(a < 10),
+#'     segments = b ~ c("group_1", "group_2"),
 #'     actions = action_levels(warn_at = 0.1, stop_at = 0.2),
 #'     label = "The `col_vals_expr()` step.",
 #'     active = FALSE
@@ -91,6 +128,7 @@
 #' - col_vals_expr:
 #'     expr: ~a%%1 == 0
 #'     preconditions: ~. %>% dplyr::filter(a < 10)
+#'     segments: b ~ c("group_1", "group_2")
 #'     actions:
 #'       warn_fraction: 0.1
 #'       stop_fraction: 0.2
@@ -205,7 +243,7 @@
 #' 
 #' @family validation functions
 #' @section Function ID:
-#' 2-18
+#' 2-19
 #' 
 #' @seealso These reexported functions (from **rlang** and **dplyr**) work
 #'   nicely within `col_vals_expr()` and its variants: [rlang::expr()],
@@ -220,6 +258,7 @@ NULL
 col_vals_expr <- function(x,
                           expr,
                           preconditions = NULL,
+                          segments = NULL,
                           actions = NULL,
                           step_id = NULL,
                           label = NULL,
@@ -227,16 +266,30 @@ col_vals_expr <- function(x,
                           active = TRUE) {
   
   if (!inherits(expr, "call")) {
+    
     if (rlang::is_formula(expr)) {
+      
       expr <- expr %>% rlang::f_rhs()
+      
     } else {
-      stop("The `expr` object must be a call or an R formula.\n",
-           "* A call can be made with the `expr()` function.\n",
-           "* An R formula can also be used, with the expression on the RHS.",
-           call. = FALSE)
+      
+      stop(
+        "The `expr` object must be a call or an R formula.\n",
+        "* A call can be made with the `expr()` function.\n",
+        "* An R formula can also be used, with the expression on the RHS.",
+        call. = FALSE
+      )
     }
   }
   
+  # Resolve segments into list
+  segments_list <- 
+    resolve_segments(
+      x = x,
+      seg_expr = segments,
+      preconditions = preconditions
+    )
+  
   if (is_a_table_object(x)) {
     
     secret_agent <-
@@ -244,6 +297,7 @@ col_vals_expr <- function(x,
       col_vals_expr(
         expr = expr,
         preconditions = preconditions,
+        segments = segments,
         label = label,
         brief = brief,
         actions = prime_actions(actions),
@@ -275,22 +329,32 @@ col_vals_expr <- function(x,
   # values in earlier validation steps
   check_step_id_duplicates(step_id, agent)
   
-  # Add a validation step
-  agent <-
-    create_validation_step(
-      agent = agent,
-      assertion_type = "col_vals_expr",
-      i_o = i_o,
-      columns_expr = NA_character_,
-      column = NA_character_,
-      values = expr,
-      preconditions = preconditions,
-      actions = covert_actions(actions, agent),
-      step_id = step_id,
-      label = label,
-      brief = brief,
-      active = active
-    )
+  # Add one or more validation steps based on the
+  # length of `segments_list`
+  for (i in seq_along(segments_list)) {
+    
+    seg_col <- names(segments_list[i])
+    seg_val <- unname(unlist(segments_list[i]))
+    
+    agent <-
+      create_validation_step(
+        agent = agent,
+        assertion_type = "col_vals_expr",
+        i_o = i_o,
+        columns_expr = NA_character_,
+        column = NA_character_,
+        values = expr,
+        preconditions = preconditions,
+        seg_expr = segments,
+        seg_col = seg_col,
+        seg_val = seg_val,
+        actions = covert_actions(actions, agent),
+        step_id = step_id,
+        label = label,
+        brief = brief,
+        active = active
+      )
+  }
   
   agent
 }
