@@ -48,16 +48,52 @@
 #' FALSE` means that any `NA`s encountered will accumulate failing test units.
 #' 
 #' @section Preconditions:
-#' Having table `preconditions` means **pointblank** will mutate the table just
-#' before interrogation. Such a table mutation is isolated in scope to the
-#' validation step(s) produced by the validation function call. Using
-#' **dplyr** code is suggested here since the statements can be translated to
-#' SQL if necessary. The code is most easily supplied as a one-sided **R**
-#' formula (using a leading `~`). In the formula representation, the `.` serves
-#' as the input data table to be transformed (e.g., 
-#' `~ . %>% dplyr::mutate(col_a = col_b + 10)`). Alternatively, a function could
-#' instead be supplied (e.g., 
-#' `function(x) dplyr::mutate(x, col_a = col_b + 10)`).
+#' Providing expressions as `preconditions` means **pointblank** will preprocess
+#' the target table table during interrogation as a preparatory step. It might
+#' happen that a particular validation requires a calculated column, some
+#' filtering of rows, or the addition of columns via a join, etc. Especially for
+#' an *agent*-based report this can be advantageous since we can develop a large
+#' validation plan with a single target table and make minor adjustments to it,
+#' as needed, along the way.
+#'
+#' The table mutation is totally isolated in scope to the validation step(s)
+#' where `preconditions` is used. Using **dplyr** code is suggested here since
+#' the statements can be translated to SQL if necessary (i.e., if the target
+#' table resides in a database). The code is most easily supplied as a one-sided
+#' **R** formula (using a leading `~`). In the formula representation, the `.`
+#' serves as the input data table to be transformed (e.g., `~ . %>%
+#' dplyr::mutate(col_b = col_a + 10)`). Alternatively, a function could instead
+#' be supplied (e.g., `function(x) dplyr::mutate(x, col_b = col_a + 10)`).
+#' 
+#' @section Segments:
+#' By using the `segments` argument, it's possible to define a particular
+#' validation with segments (or row slices) of the target table. An optional
+#' expression or set of expressions that serve to segment the target table by
+#' column values. Each expression can be given in one of two ways: (1) as column
+#' names, or (2) as a two-sided formula where the LHS holds a column name and
+#' the RHS contains the column values to segment on.
+#' 
+#' As an example of the first type of expression that can be used,
+#' `vars(a_column)` will segment the target table in however many unique values
+#' are present in the column called `a_column`. This is great if every unique
+#' value in a particular column (like different locations, or different dates)
+#' requires it's own repeating validation.
+#'
+#' With a formula, we can be more selective with which column values should be
+#' used for segmentation. Using `a_column ~ c("group_1", "group_2")` will
+#' attempt to obtain two segments where one is a slice of data where the value
+#' `"group_1"` exists in the column named `"a_column"`, and, the other is a
+#' slice where `"group_2"` exists in the same column. Each group of rows
+#' resolved from the formula will result in a separate validation step.
+#'
+#' If there are multiple `columns` specified then the potential number of
+#' validation steps will be `m` columns multiplied by `n` segments resolved.
+#'
+#' Segmentation will always occur after `preconditions` (i.e., statements that
+#' mutate the target table), if any, are applied. With this type of one-two
+#' combo, it's possible to generate labels for segmentation using an expression
+#' for `preconditions` and refer to those labels in `segments` without having to
+#' generate a separate version of the target table.
 #' 
 #' @section Actions:
 #' Often, we will want to specify `actions` for the validation. This argument,
@@ -99,6 +135,7 @@
 #'     value = 1,
 #'     na_pass = TRUE,
 #'     preconditions = ~ . %>% dplyr::filter(a < 10),
+#'     segments = b ~ c("group_1", "group_2"),
 #'     actions = action_levels(warn_at = 0.1, stop_at = 0.2),
 #'     label = "The `col_vals_lt()` step.",
 #'     active = FALSE
@@ -111,6 +148,7 @@
 #'     value: 1.0
 #'     na_pass: true
 #'     preconditions: ~. %>% dplyr::filter(a < 10)
+#'     segments: b ~ c("group_1", "group_2")
 #'     actions:
 #'       warn_fraction: 0.1
 #'       stop_fraction: 0.2
@@ -219,6 +257,7 @@ col_vals_lt <- function(x,
                         value,
                         na_pass = FALSE,
                         preconditions = NULL,
+                        segments = NULL,
                         actions = NULL,
                         step_id = NULL,
                         label = NULL,
@@ -236,6 +275,14 @@ col_vals_lt <- function(x,
   # Resolve the columns based on the expression
   columns <- resolve_columns(x = x, var_expr = columns, preconditions)
   
+  # Resolve segments into list
+  segments_list <-
+    resolve_segments(
+      x = x,
+      seg_expr = segments,
+      preconditions = preconditions
+    )
+  
   if (is_a_table_object(x)) {
     
     secret_agent <-
@@ -245,6 +292,7 @@ col_vals_lt <- function(x,
         value = value,
         na_pass = na_pass,
         preconditions = preconditions,
+        segments = segments,
         label = label,
         brief = brief,
         actions = prime_actions(actions),
@@ -258,9 +306,14 @@ col_vals_lt <- function(x,
   agent <- x
   
   if (is.null(brief)) {
+    
     brief <- 
       generate_autobriefs(
-        agent, columns, preconditions, values = value, "col_vals_lt"
+        agent = agent,
+        columns = columns,
+        preconditions = preconditions,
+        values = value,
+        assertion_type = "col_vals_lt"
       )
   }
   
@@ -276,24 +329,32 @@ col_vals_lt <- function(x,
   
   # Add one or more validation steps based on the
   # length of the `columns` variable
-  for (i in seq(columns)) {
-    
-    agent <-
-      create_validation_step(
-        agent = agent,
-        assertion_type = "col_vals_lt",
-        i_o = i_o,
-        columns_expr = columns_expr,
-        column = columns[i],
-        values = value,
-        na_pass = na_pass,
-        preconditions = preconditions,
-        actions = covert_actions(actions, agent),
-        step_id = step_id[i],
-        label = label,
-        brief = brief[i],
-        active = active
-      )
+  for (i in seq_along(columns)) {
+    for (j in seq_along(segments_list)) {
+      
+      seg_col <- names(segments_list[j])
+      seg_val <- unname(unlist(segments_list[j]))
+      
+      agent <-
+        create_validation_step(
+          agent = agent,
+          assertion_type = "col_vals_lt",
+          i_o = i_o,
+          columns_expr = columns_expr,
+          column = columns[i],
+          values = value,
+          na_pass = na_pass,
+          preconditions = preconditions,
+          seg_expr = segments,
+          seg_col = seg_col,
+          seg_val = seg_val,
+          actions = covert_actions(actions, agent),
+          step_id = step_id[i],
+          label = label,
+          brief = brief[i],
+          active = active
+        )
+    }
   }
 
   agent
