@@ -17,30 +17,32 @@
 #
 
 
+# nocov start
 # nolint start
 
-#' Print the agent information to the console
+#
+# ptblank_agent
+#
+
+#' Print the `ptblank_agent` object
 #'
-#' This function will allow the agent to print a useful report.
+#' This function will allow the agent object to print a useful HTML-based
+#' report.
 #' 
-#' @param x An agent object of class `ptblank_agent`.
+#' @param x An object of class `ptblank_agent`.
 #' @param view The value for `print()`s `browse` argument.
 #' @param ... Any additional parameters.
 #' 
 #' @keywords internal
 #' @export
 print.ptblank_agent <- function(x, view = interactive(), ...) {
-  
-  # nocov start 
-  
+
   print(get_agent_report(x), view = view, ...)
-  
-  # nocov end 
 }
 
-#' Knit print the agent information table
+#' Knit print the `ptblank_agent` object
 #'
-#' This facilitates printing of the agent report table within a knitr code
+#' This facilitates printing of the `ptblank_agent` object within a knitr code
 #' chunk.
 #'
 #' @param x An object of class `ptblank_agent`.
@@ -50,18 +52,18 @@ print.ptblank_agent <- function(x, view = interactive(), ...) {
 #' @noRd
 knit_print.ptblank_agent <- function(x, ...) {
   
-  # nocov start 
-
   # Use `knit_print()` to print in a code chunk
   knitr::knit_print(get_agent_report(x), ...)
-  
-  # nocov end 
 }
 
+#
+# ptblank_informant
+#
 
-#' Print the table information report
+#' Print the `ptblank_informant` object
 #'
-#' This function will allow the table information to be nicely printed.
+#' This function will allow the informant object to print a useful HTML-based
+#' report.
 #' 
 #' @param x An informant object of class `ptblank_informant`.
 #' @param view The value for `print()`s `browse` argument.
@@ -71,17 +73,13 @@ knit_print.ptblank_agent <- function(x, ...) {
 #' @export
 print.ptblank_informant <- function(x, view = interactive(), ...) {
   
-  # nocov start 
-  
   print(get_informant_report(x), view = view, ...)
-  
-  # nocov end 
 }
 
-#' Knit print the table information report
+#' Knit print the `ptblank_informant` object
 #'
-#' This facilitates printing of the table information report within a knitr code
-#' chunk.
+#' This facilitates printing of the `ptblank_informant` object within a knitr
+#' code chunk.
 #'
 #' @param x An object of class `ptblank_informant`.
 #' @param ... Any additional parameters.
@@ -90,14 +88,130 @@ print.ptblank_informant <- function(x, view = interactive(), ...) {
 #' @noRd
 knit_print.ptblank_informant <- function(x, ...) {
   
-  # nocov start 
-  
   # Use `knit_print()` to print in a code chunk
   knitr::knit_print(get_informant_report(x), ...)
-  
-  # nocov end 
 }
 
+#
+# ptblank_multiagent
+#
+
+#' Print the `ptblank_multiagent` object
+#'
+#' This function will allow the multiagent object to print a useful HTML-based
+#' report.
+#' 
+#' @param x An object of class `ptblank_multiagent`.
+#' @param view The value for `print()`s `browse` argument.
+#' @param ... Any additional parameters.
+#' 
+#' @keywords internal
+#' @export
+print.ptblank_multiagent <- function(x, view = interactive(), ...) {
+  
+  print(get_multiagent_report(x), view = view, ...)
+}
+
+#' Knit print the `ptblank_multiagent` object
+#'
+#' This facilitates printing of the `ptblank_multiagent` within a knitr code
+#' chunk.
+#'
+#' @param x An object of class `ptblank_multiagent`.
+#' @param ... Any additional parameters.
+#'
+#' @keywords internal
+#' @noRd
+knit_print.ptblank_multiagent <- function(x, ...) {
+  
+  # Use `knit_print()` to print in a code chunk
+  knitr::knit_print(get_multiagent_report(x), ...)
+}
+
+#
+# ptblank_multiagent_report.long
+#
+
+#' Print the `ptblank_multiagent_report.long` object
+#'
+#' This function will print the `ptblank_multiagent_report.long` object, which
+#' is an HTML-based report.
+#' 
+#' @param x An object of class `ptblank_multiagent_report.long`.
+#' @param view The value for `print()`s `browse` argument.
+#' @param ... Any additional parameters.
+#' 
+#' @keywords internal
+#' @export
+print.ptblank_multiagent_report.long <- function(x, view = interactive(), ...) {
+  
+  class(x) <- c("shiny.tag.list", "list")
+  
+  print(x, browse = view, ...)
+}
+
+#' Knit print the `ptblank_multiagent_report.long` object
+#'
+#' This facilitates printing of the `ptblank_multiagent_report.long` within a
+#' knitr code chunk.
+#'
+#' @param x An object of class `ptblank_multiagent_report.long`.
+#' @param ... Any additional parameters.
+#'
+#' @keywords internal
+#' @noRd
+knit_print.ptblank_multiagent_report.long <- function(x, ...) {
+  
+  class(x) <- c("shiny.tag.list", "list")
+  
+  # Use `knit_print()` to print in a code chunk
+  knitr::knit_print(x, ...)
+}
+
+#
+# ptblank_tbl_scan
+#
+
+#' Print the `ptblank_tbl_scan` object
+#'
+#' This function will print the `ptblank_tbl_scan` object, which is an
+#' HTML-based report.
+#'
+#' @param x An object of class `ptblank_tbl_scan`.
+#' @param ... Any additional parameters.
+#' @param view The value for `print()`s `browse` argument.
+#'
+#' @keywords internal
+#'
+#' @export
+print.ptblank_tbl_scan <- function(x, ..., view = interactive()) {
+  
+  class(x) <- c("shiny.tag.list", "list")
+  
+  print(x, browse = view, ...)
+}
+
+#' Knit print the `ptblank_tbl_scan` object
+#'
+#' This facilitates printing of the `ptblank_tbl_scan` within a knitr code
+#' chunk.
+#'
+#' @param x An object of class `ptblank_tbl_scan`.
+#' @param ... Any additional parameters.
+#'
+#' @keywords internal
+#' @noRd
+knit_print.ptblank_tbl_scan <- function(x, ...) {
+  
+  class(x) <- c("shiny.tag.list", "list")
+  
+  # Use `knit_print()` to print in a code chunk
+  knitr::knit_print(x, ...)
+}
+
+#
+# x_list_i
+#
 
 #' Print a single-step x-list to the console
 #'
@@ -110,8 +224,6 @@ knit_print.ptblank_informant <- function(x, ...) {
 #' @export
 print.x_list_i <- function(x, ...) {
   
-  # nocov start
-  
   cli::cli_div(
     theme = list(
       span.cyan = list(color = "cyan"),
@@ -164,8 +276,6 @@ print.x_list_i <- function(x, ...) {
   cli::cli_rule(
     right = ifelse(length(x$time) == 0, "NO INTERROGATION PERFORMED", "")
   )
-
-  # nocov end 
 }
 
 #' Print an x-list comprising all validation steps to the console
@@ -180,8 +290,6 @@ print.x_list_i <- function(x, ...) {
 #' @export
 print.x_list_n <- function(x, ...) {
   
-  # nocov start
-  
   cli::cli_div(
     theme = list(
       span.cyan = list(color = "cyan"),
@@ -251,8 +359,6 @@ print.x_list_n <- function(x, ...) {
   cli::cli_rule(
     right = ifelse(length(x$time) == 0, "NO INTERROGATION PERFORMED", "")
   )
-    
-  # nocov end 
 }
 
 #' Print the `action_levels` object
@@ -265,9 +371,7 @@ print.x_list_n <- function(x, ...) {
 #' @keywords internal
 #' @export
 print.action_levels <- function(x, ...) {
-  
-  # nocov start
-  
+
   has_warn_fns <- !is.null(x$fns$warn)
   has_stop_fns <- !is.null(x$fns$stop)
   has_notify_fns <- !is.null(x$fns$notify)
@@ -366,27 +470,6 @@ print.action_levels <- function(x, ...) {
   }
   
   cli::cli_rule()
-  
-  # nocov end 
-}
-
-#' Print the `ptblank_multiagent` object
-#'
-#' This function will allow the `ptblank_multiagent` to be nicely printed.
-#' 
-#' @param x An object of class `ptblank_multiagent`.
-#' @param view The value for `print()`s `browse` argument.
-#' @param ... Any additional parameters.
-#' 
-#' @keywords internal
-#' @export
-print.ptblank_multiagent <- function(x, view = interactive(), ...) {
-
-  # nocov start 
-  
-  print(get_multiagent_report(x), view = view, ...)
-  
-  # nocov end 
 }
 
 #' Print the `tbl_store` object
@@ -400,8 +483,6 @@ print.ptblank_multiagent <- function(x, view = interactive(), ...) {
 #' @export
 print.tbl_store <- function(x, ...) {
   
-  # nocov start
-  
   tbl_names <- names(x)
   
   n_tbls <- length(tbl_names)
@@ -445,8 +526,6 @@ print.tbl_store <- function(x, ...) {
   }
   
   cli::cli_rule()
-  
-  # nocov end 
 }
 
 #' Print the `read_fn` object
@@ -460,7 +539,6 @@ print.tbl_store <- function(x, ...) {
 #' @export
 print.read_fn <- function(x, ...) {
   
-  # nocov start
   tbl_name <- capture_formula(x)[1]
   tbl_formula <- capture_formula(x)[2]
   
@@ -479,8 +557,7 @@ print.read_fn <- function(x, ...) {
       "{.red {ifelse(has_given_name, '', '*')}} // {tbl_formula}"
     )
   )
-
-  # nocov end 
 }
 
 # nolint end
+# nocov end
