@@ -38,16 +38,52 @@
 #' `ends_with()`, `contains()`, `matches()`, and `everything()`.
 #' 
 #' @section Preconditions:
-#' Having table `preconditions` means **pointblank** will mutate the table just
-#' before interrogation. Such a table mutation is isolated in scope to the
-#' validation step(s) produced by the validation function call. Using
-#' **dplyr** code is suggested here since the statements can be translated to
-#' SQL if necessary. The code is most easily supplied as a one-sided **R**
-#' formula (using a leading `~`). In the formula representation, the `.` serves
-#' as the input data table to be transformed (e.g., 
-#' `~ . %>% dplyr::mutate(col_a = col_b + 10)`). Alternatively, a function could
-#' instead be supplied (e.g., 
-#' `function(x) dplyr::mutate(x, col_a = col_b + 10)`).
+#' Providing expressions as `preconditions` means **pointblank** will preprocess
+#' the target table table during interrogation as a preparatory step. It might
+#' happen that a particular validation requires a calculated column, some
+#' filtering of rows, or the addition of columns via a join, etc. Especially for
+#' an *agent*-based report this can be advantageous since we can develop a large
+#' validation plan with a single target table and make minor adjustments to it,
+#' as needed, along the way.
+#'
+#' The table mutation is totally isolated in scope to the validation step(s)
+#' where `preconditions` is used. Using **dplyr** code is suggested here since
+#' the statements can be translated to SQL if necessary (i.e., if the target
+#' table resides in a database). The code is most easily supplied as a one-sided
+#' **R** formula (using a leading `~`). In the formula representation, the `.`
+#' serves as the input data table to be transformed (e.g., `~ . %>%
+#' dplyr::mutate(col_b = col_a + 10)`). Alternatively, a function could instead
+#' be supplied (e.g., `function(x) dplyr::mutate(x, col_b = col_a + 10)`).
+#' 
+#' @section Segments:
+#' By using the `segments` argument, it's possible to define a particular
+#' validation with segments (or row slices) of the target table. An optional
+#' expression or set of expressions that serve to segment the target table by
+#' column values. Each expression can be given in one of two ways: (1) as column
+#' names, or (2) as a two-sided formula where the LHS holds a column name and
+#' the RHS contains the column values to segment on.
+#' 
+#' As an example of the first type of expression that can be used,
+#' `vars(a_column)` will segment the target table in however many unique values
+#' are present in the column called `a_column`. This is great if every unique
+#' value in a particular column (like different locations, or different dates)
+#' requires it's own repeating validation.
+#'
+#' With a formula, we can be more selective with which column values should be
+#' used for segmentation. Using `a_column ~ c("group_1", "group_2")` will
+#' attempt to obtain two segments where one is a slice of data where the value
+#' `"group_1"` exists in the column named `"a_column"`, and, the other is a
+#' slice where `"group_2"` exists in the same column. Each group of rows
+#' resolved from the formula will result in a separate validation step.
+#'
+#' If there are multiple `columns` specified then the potential number of
+#' validation steps will be `m` columns multiplied by `n` segments resolved.
+#'
+#' Segmentation will always occur after `preconditions` (i.e., statements that
+#' mutate the target table), if any, are applied. With this type of one-two
+#' combo, it's possible to generate labels for segmentation using an expression
+#' for `preconditions` and refer to those labels in `segments` without having to
+#' generate a separate version of the target table.
 #' 
 #' @section Actions:
 #' Often, we will want to specify `actions` for the validation. This argument,
@@ -87,6 +123,7 @@
 #'   rows_distinct(
 #'     columns = vars(a, b),
 #'     preconditions = ~ . %>% dplyr::filter(a < 10),
+#'     segments = b ~ c("group_1", "group_2"),
 #'     actions = action_levels(warn_at = 0.1, stop_at = 0.2),
 #'     label = "The `rows_distinct()` step.",
 #'     active = FALSE
@@ -97,6 +134,7 @@
 #' - rows_distinct:
 #'     columns: vars(a, b)
 #'     preconditions: ~. %>% dplyr::filter(a < 10)
+#'     segments: b ~ c("group_1", "group_2")
 #'     actions:
 #'       warn_fraction: 0.1
 #'       stop_fraction: 0.2
@@ -104,13 +142,13 @@
 #'     active: false
 #' ```
 #' 
-#' In practice, both of these will often be shorter. A value `columns` for
-#' columns is only necessary if checking for unique values across the some
-#' specification of columns. Arguments with default values won't be written to
-#' YAML when using [yaml_write()] (though it is acceptable to include them with
-#' their default when generating the YAML by other means). It is also possible
-#' to preview the transformation of an agent to YAML without any writing to disk
-#' by using the [yaml_agent_string()] function.
+#' In practice, both of these will often be shorter. A value for `columns` is
+#' only necessary if checking for unique values across a subset of columns.
+#' Arguments with default values won't be written to YAML when using
+#' [yaml_write()] (though it is acceptable to include them with their default
+#' when generating the YAML by other means). It is also possible to preview the
+#' transformation of an agent to YAML without any writing to disk by using the
+#' [yaml_agent_string()] function.
 #'
 #' @inheritParams col_vals_gt
 #'   
@@ -147,7 +185,7 @@
 #' 
 #' @family validation functions
 #' @section Function ID:
-#' 2-20
+#' 2-21
 #' 
 #' @name rows_distinct
 NULL
@@ -158,6 +196,7 @@ NULL
 rows_distinct <- function(x,
                           columns = NULL,
                           preconditions = NULL,
+                          segments = NULL,
                           actions = NULL,
                           step_id = NULL,
                           label = NULL,
@@ -186,6 +225,14 @@ rows_distinct <- function(x,
     columns <- resolve_columns(x = x, var_expr = columns, preconditions)
   }
   
+  # Resolve segments into list
+  segments_list <-
+    resolve_segments(
+      x = x,
+      seg_expr = segments,
+      preconditions = preconditions
+    )
+  
   if (is_a_table_object(x)) {
     
     secret_agent <- 
@@ -193,6 +240,7 @@ rows_distinct <- function(x,
       rows_distinct(
         columns = columns,
         preconditions = preconditions,
+        segments = segments,
         label = label,
         brief = brief,
         actions = prime_actions(actions),
@@ -233,22 +281,32 @@ rows_distinct <- function(x,
   # values in earlier validation steps
   check_step_id_duplicates(step_id, agent)
   
-  # Add a validation step
-  agent <-
-    create_validation_step(
-      agent = agent,
-      assertion_type = "rows_distinct",
-      i_o = i_o,
-      columns_expr = columns_expr,
-      column = list(ifelse(is.null(columns), NA_character_, columns)),
-      values = NULL,
-      preconditions = preconditions,
-      actions = covert_actions(actions, agent),
-      step_id = step_id,
-      label = label,
-      brief = brief,
-      active = active
-    )
+  # Add one or more validation steps based on the
+  # length of `segments`
+  for (i in seq_along(segments_list)) {
+    
+    seg_col <- names(segments_list[i])
+    seg_val <- unname(unlist(segments_list[i]))
+    
+    agent <-
+      create_validation_step(
+        agent = agent,
+        assertion_type = "rows_distinct",
+        i_o = i_o,
+        columns_expr = columns_expr,
+        column = list(ifelse(is.null(columns), NA_character_, columns)),
+        values = NULL,
+        preconditions = preconditions,
+        seg_expr = segments,
+        seg_col = seg_col,
+        seg_val = seg_val,
+        actions = covert_actions(actions, agent),
+        step_id = step_id,
+        label = label,
+        brief = brief,
+        active = active
+      )
+  }
 
   agent
 }
