@@ -29,22 +29,6 @@ is_ptblank_x_list <- function(x) {
   inherits(x, "x_list")
 }
 
-is_a_table_object <- function(x) {
-  inherits(x, c("data.frame", "tbl_df", "tbl_dbi", "tbl_spark"))
-}
-
-is_tbl_spark <- function(x) {
-  inherits(x, "tbl_spark")
-}
-
-is_tbl_dbi <- function(x) {
-  inherits(x, "tbl_dbi")
-}
-
-is_arrow_object <- function(x) {
-  inherits(x, "ArrowObject")
-}
-
 has_agent_intel <- function(agent) {
   inherits(agent, "has_intel")
 }
@@ -53,6 +37,26 @@ get_tbl_object <- function(agent) {
   agent$tbl
 }
 
+is_a_table_object <- function(x) {
+  inherits(x, c("data.frame", "tbl_df", "tbl_dbi", "tbl_spark"))
+}
+
+is_tbl_dbi <- function(x) {
+  inherits(x, "tbl_dbi")
+}
+
+# nocov start
+
+is_tbl_spark <- function(x) {
+  inherits(x, "tbl_spark")
+}
+
+is_arrow_object <- function(x) {
+  inherits(x, "ArrowObject")
+}
+
+# nocov end
+
 # Generate a label for the `agent` or `informant` object
 generate_label <- function(label = NULL) {
   
@@ -157,8 +161,8 @@ resolve_columns <- function(x, var_expr, preconditions) {
   if (inherits(var_expr, "quosure") &&
       var_expr %>% rlang::as_label() == "NULL") {
     
-    return(character(0))
-  } 
+    return(character(NA_character_))
+  }
   
   # nocov end
   
@@ -193,9 +197,110 @@ resolve_columns <- function(x, var_expr, preconditions) {
     }
   }
   
+  if (length(column) < 1) {
+    column <- NA_character_
+  }
+  
   column
 }
 
+#' The `resolve_segments()` function works with input from the `segments`
+#' argument, present is a variety of row-based validation functions.
+#' 
+#' @return A segment list with <column_name> = <column_value>
+#' @noRd
+resolve_segments <- function(x, seg_expr, preconditions) {
+  
+  # Return a list with an NA_character_ vector if the `seg_expr` is NULL
+  if (is.null(seg_expr)) {
+    
+    empty_vec <- c("empty" = NA_character_)
+    names(empty_vec) <- NA_character_
+    
+    return(as.list(empty_vec))
+  }
+  
+  # Upgrade single item to a list
+  if (
+    rlang::is_formula(seg_expr) ||
+    inherits(seg_expr, "quosures")
+  ) {
+    seg_expr <- list(seg_expr)
+  }
+  
+  # Verify that `seg_expr` is a list
+  if (!is.list(seg_expr)) {
+    stop(
+      "The `segments` value should be a list of two-sided formulas",
+      call. = FALSE
+    )
+  }
+  
+  segments_list <- list()
+
+  # Process each `seg_expr` element
+  for (i in seq_along(seg_expr)) {
+    
+    if (inherits(seg_expr[[i]], "quosures")) {
+      
+      if (inherits(x, c("data.frame", "tbl_df", "tbl_dbi"))) {
+        tbl <- x
+      } else if (inherits(x, ("ptblank_agent"))) {
+        tbl <- get_tbl_object(agent = x)
+      }
+      
+      if (!is.null(preconditions)) {
+        tbl <- apply_preconditions(tbl = tbl, preconditions = preconditions)
+      }
+      
+      for (j in seq_along(seg_expr[[i]])) {
+        
+        column_name <- rlang::as_label(seg_expr[[i]][[j]])
+        
+        col_seg_vals <- 
+          tbl %>%
+          dplyr::select(.env$column_name) %>%
+          dplyr::distinct() %>%
+          dplyr::pull()
+        
+        names(col_seg_vals) <- rep(column_name, length(col_seg_vals))
+        
+        segments_list <- c(segments_list, as.list(col_seg_vals))
+      }
+    }
+    
+    if (rlang::is_formula(seg_expr[[i]])) {
+  
+      group_formula <- seg_expr[[i]]
+      
+      # Determine if this is a two-sided formula
+      if (
+        is.null(rlang::f_lhs(group_formula)) ||
+        is.null(rlang::f_rhs(group_formula))
+      ) {
+        stop(
+          "Any formulas provided for `segments` must be two-sided",
+          call. = FALSE
+        )
+      }
+      
+      col_seg_vals <- rlang::eval_bare(rlang::f_rhs(group_formula))
+      
+      column_name <- rlang::as_label(rlang::f_lhs(group_formula))
+      
+      if (grepl("^vars\\(.+\\)$", column_name)) {
+        column_name <- gsub("(vars\\(|\\))", "", column_name)
+      }
+      
+      names(col_seg_vals) <- rep(column_name, length(col_seg_vals))
+      
+      segments_list <- c(segments_list, as.list(col_seg_vals))
+    }
+  }
+  
+  segments_list
+}
+
 normalize_step_id <- function(step_id, columns, agent) {
 
   if (is.null(step_id)) {
@@ -280,7 +385,21 @@ check_step_id_duplicates <- function(step_id, agent) {
       "Just after step index `", error_at_index,
       "`, the following `step_id` has been ",
       "seen as used in a previous validation step:\n",
-      " * \"", a_duplicate_step_id, "\"",
+      "* \"", a_duplicate_step_id, "\"",
+      call. = FALSE
+    )
+  }
+}
+
+check_is_a_table_object <- function(tbl) {
+
+  if (!is_a_table_object(tbl)) {
+    
+    stop(
+      "The object supplied is not a table object, valid tables are:\n",
+      "* data frames, tibbles, or data.table objects\n",
+      "* database tables (`tbl_dbi`)\n",
+      "* `tbl_spark` objects (via the sparklyr package)",
       call. = FALSE
     )
   }
@@ -574,6 +693,8 @@ get_tbl_information_dbi <- function(tbl) {
   )
 }
 
+# nocov start
+
 get_tbl_information_arrow <- function(tbl) {
 
   schema_cap <- utils::capture.output(tbl$schema)[-1][seq_len(ncol(tbl))]
@@ -614,7 +735,9 @@ get_tbl_information_arrow <- function(tbl) {
     r_col_types = r_col_types,
     db_col_types = db_col_types
   )
-} 
+}
+
+# nocov end
 
 pb_fmt_number <- function(x,
                           decimals = 2,
@@ -1026,6 +1149,8 @@ pb_quantile_stats <- function(data_column,
   
   if (is_tbl_spark(data_column)) {
     
+    # nocov start
+    
     column_name <- colnames(data_column)
     
     quantile <- 
@@ -1038,6 +1163,8 @@ pb_quantile_stats <- function(data_column,
     
     return(quantile)
     
+    # nocov end
+    
   } else if (inherits(data_column, "data.frame")) {
     
     quantile <- 
@@ -1092,8 +1219,10 @@ pb_quantile_stats <- function(data_column,
         as.numeric() %>%
         round(2)
     }
+    
   } else {
-    stop("The table type isn't yet supported", call. = FALSE)
+    
+    stop("This table type isn't yet supported", call. = FALSE)
   }
   
   quantile
@@ -1138,3 +1267,19 @@ cli_ident <- function(x,
 
   paste0(initial, gsub("\n", paste0("\n", indent), x))
 }
+
+print_time <- function(time_diff_s) {
+  
+  if (time_diff_s < 1) {
+    return("")
+  } else {
+    return(
+      paste0(
+        " {.time_taken (",
+        round(time_diff_s, 1) %>%
+          formatC(format = "f", drop0trailing = FALSE, digits = 1),
+        " s)}"
+      )
+    )
+  }
+}
