@@ -51,10 +51,13 @@ utils::globalVariables(
     "__mean__",
     "__var__",
     "a",
+    "a__",
     "action",
     "actions",
     "active",
     "agent",
+    "alpha_2",
+    "alpha_3",
     "::all_na::",
     "assertion_type",
     "bin_num",
@@ -65,9 +68,11 @@ utils::globalVariables(
     "columns_expr",
     "col_element",
     "col_name",
+    "col_num",
     "condition",
     "count",
     "Count",
+    "country_alpha_3",
     "::cut_group::",
     "data_type",
     "DATA_TYPE",
@@ -98,6 +103,7 @@ utils::globalVariables(
     "n_fail",
     "n_pass",
     "na_pass",
+    "name_en",
     "N",
     "N_pts",
     "N_val",
@@ -109,7 +115,48 @@ utils::globalVariables(
     "pb_is_good_1_",
     "pb_is_good_2_",
     "pb_lagged_difference_",
+    "pb_vin_001_",
+    "pb_vin_001_w",
+    "pb_vin_002_",
+    "pb_vin_002_w",
+    "pb_vin_003_",
+    "pb_vin_003_w",
+    "pb_vin_004_",
+    "pb_vin_004_w",
+    "pb_vin_005_",
+    "pb_vin_005_w",
+    "pb_vin_006_",
+    "pb_vin_006_w",
+    "pb_vin_007_",
+    "pb_vin_007_w",
+    "pb_vin_008_",
+    "pb_vin_008_w",
+    "pb_vin_009_",
+    "pb_vin_009_w",
+    "pb_vin_010_",
+    "pb_vin_010_w",
+    "pb_vin_011_",
+    "pb_vin_011_w",
+    "pb_vin_012_",
+    "pb_vin_012_w",
+    "pb_vin_013_",
+    "pb_vin_013_w",
+    "pb_vin_014_",
+    "pb_vin_014_w",
+    "pb_vin_015_",
+    "pb_vin_015_w",
+    "pb_vin_016_",
+    "pb_vin_016_w",
+    "pb_vin_017_",
+    "pb_vin_017_w",
+    "pb_vin_all_",
+    "pb_vin_chk_",
+    "pb_vin_mod_",
+    "pb_vin_nch_",
+    "pb_vin_sum_",
+    "pb_vin_sum_uw",
     "pct",
+    "postal_code_format",
     "precon",
     "preconditions",
     "q_1",
@@ -117,15 +164,19 @@ utils::globalVariables(
     "%REGEXP%",
     "regexp_matches",
     "RLIKE",
+    "rowid",
     "S",
     "schema",
     "sd",
+    "seg_expr",
     "set_element",
     "S_pts",
     "S_val",
     "sha1",
     "status_color",
     "step_id",
+    "str_length__",
+    "subd_name",
     "tbl_checked",
     "time_str",
     "total_pts",
@@ -147,6 +198,9 @@ utils::globalVariables(
   
   register_s3_method("knitr", "knit_print", "ptblank_agent")
   register_s3_method("knitr", "knit_print", "ptblank_informant")
+  register_s3_method("knitr", "knit_print", "ptblank_multiagent")
+  register_s3_method("knitr", "knit_print", "ptblank_multiagent_report.long")
+  register_s3_method("knitr", "knit_print", "ptblank_tbl_scan")
   
   if ("knitr" %in% loadedNamespaces()) {
     validate_rmd_setup()
